==> aria2_1.15.1.orig.tar.bz2: aria2-1.15.1/src/LpdReceiveMessageCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_LPD_RECEIVE_MESSAGE_COMMAND_H
#define D_LPD_RECEIVE_MESSAGE_COMMAND_H

#include "Command.h"
#include "SharedHandle.h"

namespace aria2 {

class LpdMessageReceiver;
class DownloadEngine;
class SocketCore;

class LpdReceiveMessageCommand:public Command {
private:
  SharedHandle<LpdMessageReceiver> receiver_;
  DownloadEngine* e_;
public:
  LpdReceiveMessageCommand
  (cuid_t cuid, const SharedHandle<LpdMessageReceiver>& receiver,
   DownloadEngine* e);
  virtual ~LpdReceiveMessageCommand();

  virtual bool execute();

  const SharedHandle<LpdMessageReceiver>& getLpdMessageReceiver() const
  {
    return receiver_;
  }
};

} // namespace aria2

#endif // D_LPD_RECEIVE_MESSAGE_COMMAND_H

==> aria2_1.18.1.orig.tar.bz2: aria2-1.18.1/src/LpdReceiveMessageCommand.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_LPD_RECEIVE_MESSAGE_COMMAND_H
#define D_LPD_RECEIVE_MESSAGE_COMMAND_H

#include "Command.h"

#include <memory>

namespace aria2 {

class LpdMessageReceiver;
class DownloadEngine;
class SocketCore;

class LpdReceiveMessageCommand:public Command {
private:
  std::shared_ptr<LpdMessageReceiver> receiver_;
  DownloadEngine* e_;
public:
  LpdReceiveMessageCommand
  (cuid_t cuid, const std::shared_ptr<LpdMessageReceiver>& receiver,
   DownloadEngine* e);
  virtual ~LpdReceiveMessageCommand();

  virtual bool execute() CXX11_OVERRIDE;

  const std::shared_ptr<LpdMessageReceiver>& getLpdMessageReceiver() const
  {
    return receiver_;
  }
};

} // namespace aria2

#endif // D_LPD_RECEIVE_MESSAGE_COMMAND_H
